/* guile-irrlicht --- GNU Guile bindings for Irrlicht Engine

   Copyright (C) 2020 Javier Sancho <jsf@jsancho.org>

   This file is part of guile-irrlicht.

   guile-irrlicht is free software; you can redistribute it and/or modify
   it under the terms of the GNU Lesser General Public License as
   published by the Free Software Foundation; either version 3 of the
   License, or (at your option) any later version.

   guile-irrlicht is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with guile-irrlicht. If not, see
   <http://www.gnu.org/licenses/>.
*/

#include <irrlicht/irrlicht.h>
#include <libguile.h>
#include "animated-mesh-md2.h"
#include "animated-mesh-scene-node.h"
#include "gsubr.h"
#include "wrapped.h"

using namespace irr;

SCM
IAnimatedMeshSceneNode_setAnimationSpeed (SCM animated_mesh_scene_node,
                                          SCM frames_per_second)
{
  scene::IAnimatedMeshSceneNode* node =
    (scene::IAnimatedMeshSceneNode*) scm_to_irr_pointer (animated_mesh_scene_node);
  node->setAnimationSpeed (scm_to_double (frames_per_second));
  return SCM_UNSPECIFIED;
}

SCM
IAnimatedMeshSceneNode_setFrameLoop (SCM animated_mesh_scene_node,
                                     SCM begin,
                                     SCM end)
{
  return scm_from_bool
    (((scene::IAnimatedMeshSceneNode*)scm_to_irr_pointer (animated_mesh_scene_node))->
     setFrameLoop (scm_to_int32 (begin),
                   scm_to_int32 (end)));
}

SCM
IAnimatedMeshSceneNode_setMD2Animation (SCM animated_mesh_scene_node,
                                        SCM anim)
{
  return scm_from_bool
    (((scene::IAnimatedMeshSceneNode*)scm_to_irr_pointer (animated_mesh_scene_node))->
     setMD2Animation (scm_to_md2_animation_type (anim)));
}

void
init_animated_mesh_scene_node (void)
{
  DEFINE_GSUBR ("IAnimatedMeshSceneNode_setAnimationSpeed", 2, 0, 0,
                IAnimatedMeshSceneNode_setAnimationSpeed);
  DEFINE_GSUBR ("IAnimatedMeshSceneNode_setFrameLoop", 3, 0, 0,
                IAnimatedMeshSceneNode_setFrameLoop);
  DEFINE_GSUBR ("IAnimatedMeshSceneNode_setMD2Animation", 2, 0, 0,
                IAnimatedMeshSceneNode_setMD2Animation);
}
